//package com.ruoyi.system.controller;
//
//import java.util.List;
//import javax.servlet.http.HttpServletResponse;
//import org.springframework.security.access.prepost.PreAuthorize;
//import org.springframework.beans.factory.annotation.Autowired;
//import org.springframework.web.bind.annotation.GetMapping;
//import org.springframework.web.bind.annotation.PostMapping;
//import org.springframework.web.bind.annotation.PutMapping;
//import org.springframework.web.bind.annotation.DeleteMapping;
//import org.springframework.web.bind.annotation.PathVariable;
//import org.springframework.web.bind.annotation.RequestBody;
//import org.springframework.web.bind.annotation.RequestMapping;
//import org.springframework.web.bind.annotation.RestController;
//import com.ruoyi.common.annotation.Log;
//import com.ruoyi.common.core.controller.BaseController;
//import com.ruoyi.common.core.domain.AjaxResult;
//import com.ruoyi.common.enums.BusinessType;
//import com.ruoyi.system.domain.Message;
//import com.ruoyi.system.service.IMessageService;
//import com.ruoyi.common.utils.poi.ExcelUtil;
//import com.ruoyi.common.core.page.TableDataInfo;
//
///**
// * 消息Controller
// *
// * @author haotian
// * @date 2024-10-28
// */
//@RestController
//@RequestMapping("/system/message")
//public class MessageController extends BaseController
//{
//    @Autowired
//    private IMessageService messageService;
//
//    /**
//     * 查询消息列表
//     */
//    @PreAuthorize("@ss.hasPermi('system:message:list')")
//    @GetMapping("/list")
//    public TableDataInfo list(Message message)
//    {
//        startPage();
//        List<Message> list = messageService.selectMessageList(message);
//        return getDataTable(list);
//    }
//
//    /**
//     * 导出消息列表
//     */
//    @PreAuthorize("@ss.hasPermi('system:message:export')")
//    @Log(title = "消息", businessType = BusinessType.EXPORT)
//    @PostMapping("/export")
//    public void export(HttpServletResponse response, Message message)
//    {
//        List<Message> list = messageService.selectMessageList(message);
//        ExcelUtil<Message> util = new ExcelUtil<Message>(Message.class);
//        util.exportExcel(response, list, "消息数据");
//    }
//
//    /**
//     * 获取消息详细信息
//     */
//    @PreAuthorize("@ss.hasPermi('system:message:query')")
//    @GetMapping(value = "/{messageId}")
//    public AjaxResult getInfo(@PathVariable("messageId") Long messageId)
//    {
//        return success(messageService.selectMessageByMessageId(messageId));
//    }
//
//    /**
//     * 新增消息
//     */
//    @PreAuthorize("@ss.hasPermi('system:message:add')")
//    @Log(title = "消息", businessType = BusinessType.INSERT)
//    @PostMapping
//    public AjaxResult add(@RequestBody Message message)
//    {
//        return toAjax(messageService.insertMessage(message));
//    }
//
//    /**
//     * 修改消息
//     */
//    @PreAuthorize("@ss.hasPermi('system:message:edit')")
//    @Log(title = "消息", businessType = BusinessType.UPDATE)
//    @PutMapping
//    public AjaxResult edit(@RequestBody Message message)
//    {
//        return toAjax(messageService.updateMessage(message));
//    }
//
//    /**
//     * 删除消息
//     */
//    @PreAuthorize("@ss.hasPermi('system:message:remove')")
//    @Log(title = "消息", businessType = BusinessType.DELETE)
//	@DeleteMapping("/{messageIds}")
//    public AjaxResult remove(@PathVariable Long[] messageIds)
//    {
//        return toAjax(messageService.deleteMessageByMessageIds(messageIds));
//    }
//}
